@@ -1,4 +1,4 @@
-/* Copyright 2010,2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2010,2011,2014,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -42,6 +42,10 @@
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 16 jul 2010     **/
 /**                                 to   : 15 apr 2011     **/
+/**                # Version 6.0  : from : 11 sep 2011     **/
+/**                                 to   : 31 aug 2014     **/
+/**                # Version 7.0  : from : 17 jan 2023     **/
+/**                                 to   : 17 jan 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -49,8 +53,6 @@
 **  The defines and includes.
 */
 
-#define BDGRAPH_BIPART_EX
-
 #include "module.h"
 #include "common.h"
 #include "dgraph.h"
@@ -105,8 +107,8 @@ const BdgraphBipartExParam * restrict const paraptr) /*+ Method parameters +*/
   size_t                sortsiz;
   Gnum                  reduloctab[5];
   Gnum                  reduglbtab[5];
+  Gnum                  domndist;
   Gnum                  partval;
-  Gnum                  domdist;
 
   const Gnum * restrict const vertloctax = grafptr->s.vertloctax; /* Fast accesses */
   const Gnum * restrict const vendloctax = grafptr->s.vendloctax;
@@ -175,7 +177,7 @@ const BdgraphBipartExParam * restrict const paraptr) /*+ Method parameters +*/
     return (1);
   }
 
-  domdist = (Gnum) grafptr->domdist;
+  domndist = (Gnum) grafptr->domndist;
 
   edgegsttax = grafptr->s.edgegsttax;
   edlolocval = 1;                                 /* Assume no edge loads */
@@ -207,7 +209,7 @@ const BdgraphBipartExParam * restrict const paraptr) /*+ Method parameters +*/
       partdlt   = partval ^ partend;              /* Inverse of partdlt, because "partval" is the opposite */
       commgain += (2 * partdlt - 1) * edlolocval; /* Since partdlt has reversed meaning, reverse gain too  */
     }
-    commgain *= domdist;                          /* Adjust internal gains with respect to external gains */
+    commgain *= domndist;                         /* Adjust internal gains with respect to external gains */
     if (veexloctax != NULL)
       commgain += (2 * partval - 1) * veexloctax[vertlocnum]; /* Partval has reversed meaning */
 
@@ -397,12 +399,12 @@ const BdgraphBipartExParam * restrict const paraptr) /*+ Method parameters +*/
     vertlocnum = grafptr->s.baseval;
     procsidnbr = grafptr->s.procsidnbr;
     procsidnum = 0;
-    procsidval = procsidtab[procsidnum ++];  
+    procsidval = procsidtab[procsidnum ++];
 
     while (1) {                                   /* Scan all vertices which have foreign neighbors */
       while (procsidval < 0) {
         vertlocnum -= (Gnum) procsidval;
-        procsidval  = procsidtab[procsidnum ++];  
+        procsidval  = procsidtab[procsidnum ++];
       }
 
       if (flagVal (flagloctab, vertlocnum) == 0) { /* If vertex not already processed */
@@ -476,7 +478,7 @@ loop_exit : ;
   reduloctab[0] = grafptr->fronlocnbr;
   reduloctab[1] = grafptr->complocload0;
   reduloctab[2] = grafptr->complocsize0;
-  reduloctab[3] = commlocgain * domdist;          /* Send internal gain */
+  reduloctab[3] = commlocgain * domndist;         /* Send internal gain */
   reduloctab[4] = commlocgainextn * 2;            /* Send external gain */
   if (MPI_Allreduce (reduloctab, reduglbtab, 5, GNUM_MPI, MPI_SUM, grafptr->s.proccomm) != MPI_SUCCESS) {
     errorPrint ("bdgraphBipartEx: communication error (5)");
@@ -488,6 +490,7 @@ loop_exit : ;
   grafptr->compglbsize0     = reduglbtab[2];
   grafptr->commglbload     += reduglbtab[3] / 2 + reduglbtab[4]; /* Add modifications, counted twice for internal gain */
   grafptr->commglbgainextn -= reduglbtab[4];      /* Account for modifications in external gain                        */
+  grafptr->bbalglbval       = (double) ((grafptr->compglbload0dlt < 0) ? (- grafptr->compglbload0dlt) : grafptr->compglbload0dlt) / (double) grafptr->compglbload0avg;
 
 #ifdef SCOTCH_DEBUG_BDGRAPH2
   if (bdgraphCheck (grafptr) != 0) {
