@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2018,2023 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -45,6 +45,8 @@
 /**                                 to   : 04 nov 2010     **/
 /**                # Version 6.0  : from : 08 may 2018     **/
 /**                                 to   : 07 jun 2018     **/
+/**                # Version 7.0  : from : 17 jan 2023     **/
+/**                                 to   : 10 aug 2023     **/
 /**                                                        **/
 /************************************************************/
 
@@ -57,13 +59,14 @@
 #define DORDERTAGPERI               0
 
 /*+ Column block separation tree cell flags.
-    The DORDERCBLKNEDI value must correspond
-    to a single bit and be equal to the
-    ORDERCBLKNEDI value.                     +*/
+    They must be equal to the same values
+    as for the Order flag structure.         +*/
 
-#define DORDERCBLKNONE              0x0000        /*+ Not yet assigned                 +*/
-#define DORDERCBLKNEDI              0x0001        /*+ Nested dissection separator node +*/
-#define DORDERCBLKLEAF              0x0004        /*+ Distributed leaf                 +*/
+#define DORDERCBLKNONE              ORDERCBLKNONE /*+ Not yet assigned                 +*/
+#define DORDERCBLKNEDI              ORDERCBLKNEDI /*+ Nested dissection separator node +*/
+#define DORDERCBLKDICO              ORDERCBLKDICO /*+ Disconnected components node     +*/
+#define DORDERCBLKSEQU              ORDERCBLKSEQU /*+ Sequentially dependent node      +*/
+#define DORDERCBLKLEAF              ORDERCBLKLEAF /*+ Distributed leaf                 +*/
 
 /*
 **  The type and structure definitions.
@@ -86,17 +89,17 @@ typedef struct DorderIndex_ {
     ordering.                                        +*/
 
 typedef struct DorderLink_ {
-  struct DorderLink_ *              nextptr;      /*+ Pointer to previous column block +*/
-  struct DorderLink_ *              prevptr;      /*+ Pointer to next column block     +*/
+  struct DorderLink_ *      nextptr;              /*+ Pointer to previous column block +*/
+  struct DorderLink_ *      prevptr;              /*+ Pointer to next column block     +*/
 } DorderLink;
 
 /*+ Centralized column block node. +*/
 
 typedef struct DorderNode_ {
-  Gnum                              fathnum;      /*+ Number of father in centralized node array        +*/
-  int                               typeval;      /*+ Centralized type of tree node                     +*/
-  Gnum                              vnodnbr;      /*+ Number of nodes in this column block              +*/
-  Gnum                              cblknum;      /*+ Rank of column block in father column block array +*/
+  Gnum                      fathnum;              /*+ Number of father in centralized node array        +*/
+  int                       typeval;              /*+ Centralized type of tree node                     +*/
+  Gnum                      vnodnbr;              /*+ Number of nodes in this column block              +*/
+  Gnum                      cblknum;              /*+ Rank of column block in father column block array +*/
 } DorderNode;
 
 /*+ Distributed column-block tree cell. Each
@@ -112,25 +115,25 @@ typedef struct DorderNode_ {
     traversal.                                 +*/
 
 typedef struct DorderCblk_ {
-  DorderLink                        linkdat;      /*+ Link to other blocks. TRICK: FIRST             +*/
-  struct Dorder_ *                  ordelocptr;   /*+ Pointer to local distributed ordering          +*/
-  int                               typeval;      /*+ Distributed type of tree node                  +*/
-  DorderIndex                       fathnum;      /*+ Master index of parent column block            +*/
-  DorderIndex                       cblknum;      /*+ Master index of this column block              +*/
-  Gnum                              ordeglbval;   /*+ Un-based starting index of inverse permutation +*/
-  Gnum                              vnodglbnbr;   /*+ Number of node vertices in subtree             +*/
-  Gnum                              cblkfthnum;   /*+ Rank of node in father column block array      +*/
+  DorderLink                linkdat;              /*+ Link to other blocks. TRICK: FIRST             +*/
+  struct Dorder_ *          ordelocptr;           /*+ Pointer to local distributed ordering          +*/
+  int                       typeval;              /*+ Distributed type of tree node                  +*/
+  DorderIndex               fathnum;              /*+ Master index of parent column block            +*/
+  DorderIndex               cblknum;              /*+ Master index of this column block              +*/
+  Gnum                      ordeglbval;           /*+ Un-based starting index of inverse permutation +*/
+  Gnum                      vnodglbnbr;           /*+ Number of node vertices in subtree             +*/
+  Gnum                      cblkfthnum;           /*+ Rank of node in father column block array      +*/
   union {
     struct {                                      /*+ Fragment of inverse permutation                +*/
-      Gnum                          ordelocval;   /*+ Starting index of inverse permutation          +*/
-      Gnum                          vnodlocnbr;   /*+ Number of node vertices in fragment            +*/
-      Gnum *                        periloctab;   /*+ Pointer to inverse permutation fragment        +*/
-      Gnum                          nodelocnbr;   /*+ Number of local column blocks                  +*/
-      DorderNode *                  nodeloctab;   /*+ Array of local column blocks                   +*/
-      Gnum                          cblklocnum;   /*+ Local number of first local column block       +*/
+      Gnum                  ordelocval;           /*+ Starting index of inverse permutation          +*/
+      Gnum                  vnodlocnbr;           /*+ Number of node vertices in fragment            +*/
+      Gnum *                periloctab;           /*+ Pointer to inverse permutation fragment        +*/
+      Gnum                  nodelocnbr;           /*+ Number of local column blocks                  +*/
+      DorderNode *          nodeloctab;           /*+ Array of local column blocks                   +*/
+      Gnum                  cblklocnum;           /*+ Local number of first local column block       +*/
     } leaf;
     struct {                                      /*+ Fragment of inverse permutation                +*/
-      Gnum                          cblkglbnbr;   /*+ Number of descendent nodes (2 or 3)            +*/
+      Gnum                  cblkglbnbr;           /*+ Number of descendent nodes (2 or 3)            +*/
     } nedi;
   } data;
 } DorderCblk;
@@ -141,8 +144,10 @@ typedef struct DorderCblk_ {
     of the participating processes.
     For the sake of consistency between orderings
     that have been produced either from graphs or
-    meshes, whether centralized or distributed, all
-    ordering values are based from baseval.         +*/
+    meshes, whether centralized or distributed,
+    all ordering values are based from baseval.
+    However, distributed column block indices
+    themselves are not based.                     +*/
 
 typedef struct Dorder_ {
   Gnum                      baseval;              /*+ Base value for structures                                                      +*/
@@ -163,22 +168,22 @@ typedef struct Dorder_ {
 int                         dorderInit          (Dorder * const, const Gnum, const Gnum, MPI_Comm);
 void                        dorderExit          (Dorder * const);
 void                        dorderFree          (Dorder * const);
-#ifdef DGRAPH_H
+#ifdef SCOTCH_DGRAPH_H
 int                         dorderPerm          (const Dorder * const, const Dgraph * const, Gnum * const);
 int                         dorderSave          (const Dorder * const, const Dgraph * const, FILE * const);
 int                         dorderSaveBlock     (const Dorder * const, const Dgraph * const, FILE * const);
 int                         dorderSaveMap       (const Dorder * const, const Dgraph * const, FILE * const);
 int                         dorderSaveTree      (const Dorder * const, const Dgraph * const, FILE * const);
-#ifdef ORDER_H
+#ifdef SCOTCH_ORDER_H
 int                         dorderSaveTree2     (const Dorder * restrict const, const Dgraph * restrict const, FILE * restrict const, int (*) (const Order * const, const Gnum * const, FILE * const));
-#endif /* ORDER_H */
-#endif /* DGRAPH_H */
+#endif /* SCOTCH_ORDER_H */
+#endif /* SCOTCH_DGRAPH_H */
 Gnum                        dorderCblkDist      (const Dorder * restrict const);
 int                         dorderTreeDist      (const Dorder * restrict const, const Dgraph * restrict const, Gnum * restrict const, Gnum * restrict const);
-#ifdef ORDER_H
+#ifdef SCOTCH_ORDER_H
 int                         dorderGather        (const Dorder * const, Order * const);
 int                         dorderGatherTree    (const Dorder * const, Order * const, const int);
-#endif /* ORDER_H */
+#endif /* SCOTCH_ORDER_H */
 
 DorderCblk *                dorderFrst          (Dorder * const);
 DorderCblk *                dorderNew           (DorderCblk * const, MPI_Comm);
